@@ -46,7 +46,7 @@ qx.Class.define("callbackery.ui.plugin.Form", {
                     // their course
                     //window.setTimeout(function(){
                     qx.bom.Event.fire(el,'tap');
-                    qx.dom.Element.remove(el)
+                    qx.dom.Element.remove(el);
                     //},0);
                     break;
             }
