@@ -25,6 +25,21 @@ All the methods of L<CallBackery::GuiPlugin::AbstractTable> plus:
 
 =cut
 
+has formCfg => sub {
+    my $self = shift;
+    my $db = $self->user->db;
+
+    return [
+        {
+            key => 'song_title',
+            widget => 'text',
+            set => {
+                placeholder => 'Song Title',
+            },
+        },
+    ]
+};
+
 =head2 tableCfg
 
 
@@ -123,26 +138,38 @@ has actionCfg => sub {
                 my $id = $args->{selection}{song_id};
                 die mkerror(4992,"You have to select a song first")
                     if not $id;
-                $self->user->db->deleteData('song',$id);
                 return {
-                    action => 'reload'
+#                    action => 'reload'
                 };
             }
         }
     ];
 };
 
+sub _getFilter {
+    my $self = shift;
+    my $search = shift;
+    my $filter = '';
+    my $dbh = $self->user->db->dbh;
+    if ( $search ){
+        $filter = "WHERE song_title LIKE ".$dbh->quote('%'.$search);
+    }
+    return $filter;
+}
+
 sub getTableRowCount {
     my $self = shift;
     my $args = shift;
+    my $filter = $self->_getFilter($args->{formData}{song_title});
     my $dbh = $self->user->db->dbh;
-    return ($dbh->selectrow_array('SELECT count(song_id) FROM song'))[0];
+    return ($dbh->selectrow_array("SELECT count(song_id) FROM song $filter"))[0];
 }
 
 sub getTableData {
     my $self = shift;
     my $args = shift;
     my $dbh = $self->user->db->dbh;
+    my $filter = $self->_getFilter($args->{formData}{song_title});
     my $SORT ='';
     if ($args->{sortColumn}){
         $SORT = 'ORDER BY '.$dbh->quote_identifier($args->{sortColumn});
@@ -151,6 +178,7 @@ sub getTableData {
     return $dbh->selectall_arrayref(<<"SQL",{Slice => {}}, $args->{lastRow}-$args->{firstRow}+1,$args->{firstRow});
 SELECT *
 FROM song
+$filter
 $SORT
 LIMIT ? OFFSET ?
 SQL
@@ -161,14 +189,14 @@ __END__
 
 =head1 COPYRIGHT
 
-Copyright (c) <%= $p->{year} %> by <%= $p->{fullName} %>. All rights reserved.
+Copyright (c) 2015 by Tobias Oetiker. All rights reserved.
 
 =head1 AUTHOR
 
-S<<%== $p->{fullName} %> E<lt><%= $p->{email} %>E<gt>>
+S<Tobias Oetiker E<lt>tobi@oetiker.chE<gt>>
 
 =head1 HISTORY
 
- <%= $p->{date} %> to 0.0 first version
+ 2015-34-08/27/15 to 0.0 first version
 
 =cut
